templates

package
v1.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateEncodedPath

func CreateEncodedPath(currentPath string, fileName string) string

CreateEncodedPath creates a base64-encoded path combining current path and file name

func CreateFileRow

func CreateFileRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, customPaths map[string]string, readOnly bool, formatFileSize func(int64) (float64, string)) string

CreateFileRow generates HTML for a file row in the file listing

func CreateFolderRow

func CreateFolderRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, readOnly bool) string

CreateFolderRow generates HTML for a folder row in the file listing

func CreateZipButton

func CreateZipButton(currentPath string) string

CreateZipButton generates HTML for the zip download button

func IsTextFile

func IsTextFile(fileName string) bool

IsTextFile determines if a file can be read as text based on its extension

Types

This section is empty.

Jump to