Documentation
¶
Index ¶
- func CreateEncodedPath(currentPath string, fileName string) string
- func CreateFileRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, ...) string
- func CreateFolderRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, readOnly bool) string
- func CreateZipButton(currentPath string) string
- func IsTextFile(fileName string) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateEncodedPath ¶
CreateEncodedPath creates a base64-encoded path combining current path and file name
func CreateFileRow ¶
func CreateFileRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, customPaths map[string]string, readOnly bool, formatFileSize func(int64) (float64, string)) string
CreateFileRow generates HTML for a file row in the file listing
func CreateFolderRow ¶
func CreateFolderRow(file fs.DirEntry, currentPath string, fileInfo os.FileInfo, readOnly bool) string
CreateFolderRow generates HTML for a folder row in the file listing
func CreateZipButton ¶
CreateZipButton generates HTML for the zip download button
func IsTextFile ¶
IsTextFile determines if a file can be read as text based on its extension
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.